package com.rhthacks.android.dbpull;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;

import android.os.Environment;

/**
 * For non-rooted phones. Use this library to pull sqlite database from data
 * directory and store it in your sdcard.
 * 
 * @author Rohit
 * 
 */
public class PullDatabase {

	/**
	 * @param pkgname
	 *            application package name. Use of getPackageName() method is
	 *            recommended
	 * @param yourDBname
	 *            name of your database
	 * @param SD_file_path
	 *            path of file with file name where you want to save it on sdcard
	 * @throws IOException
	 */
	public static void pull(String pkgname, String yourDBname,
			String SD_file_path) throws IOException {
		File sd = Environment.getExternalStorageDirectory();
		File data = Environment.getDataDirectory();

		if (sd.canWrite()) {

			String currentDBPath = "/data/" + pkgname + "/databases/"
					+ yourDBname;
			String backupDBPath = SD_file_path;

			File currentDB = new File(data, currentDBPath);
			File backupDB = new File(backupDBPath);

			new File(backupDB.getParent()).mkdirs();
			
			if (backupDB.exists())
				throw new IOException("The file already exists");

			if (currentDB.exists()) {
				copy(currentDB, backupDB);
			}

		}
	}

	/**
	 * 
	 * @param from source file ( /data/data/.../databases/..)
	 * @param to destination file 
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	private static void copy(File from, File to) throws FileNotFoundException,
			IOException {
		FileChannel src = null;
		FileChannel dst = null;
		try {
			src = new FileInputStream(from).getChannel();
			dst = new FileOutputStream(to).getChannel();
			dst.transferFrom(src, 0, src.size());
		} finally {
			if (src != null)
				src.close();
			if (dst != null)
				dst.close();
		}
	}
}
